package com.ruoyi.project.asset.service;

import java.util.List;
import com.ruoyi.project.asset.domain.TSpecdevMain;

/**
 * 设备总Service接口
 * 
 * @author ruoyi
 * @date 2022-10-09
 */
public interface ITSpecdevMainService 
{
    /**
     * 查询设备总
     * 
     * @param id 设备总ID
     * @return 设备总
     */
    public TSpecdevMain selectTSpecdevMainById(Long id);

    /**
     * 查询设备总列表
     * 
     * @param tSpecdevMain 设备总
     * @return 设备总集合
     */
    public List<TSpecdevMain> selectTSpecdevMainList(TSpecdevMain tSpecdevMain);

    /**
     * 新增设备总
     * 
     * @param tSpecdevMain 设备总
     * @return 结果
     */
    public int insertTSpecdevMain(TSpecdevMain tSpecdevMain);

    /**
     * 修改设备总
     * 
     * @param tSpecdevMain 设备总
     * @return 结果
     */
    public int updateTSpecdevMain(TSpecdevMain tSpecdevMain);

    /**
     * 批量删除设备总
     * 
     * @param ids 需要删除的设备总ID
     * @return 结果
     */
    public int deleteTSpecdevMainByIds(Long[] ids);

    /**
     * 删除设备总信息
     * 
     * @param id 设备总ID
     * @return 结果
     */
    public int deleteTSpecdevMainById(Long id);
}
